@@ -114,7 +114,8 @@ returnCluster <- function() {
 	
 
 	if (.Platform$OS.type == 'windows') {
-		if (!exists('readRegistry')) { readRegistry <- function(...)(1) } #This is a hack to stop the check NOTE: .detectCores: no visible global function definition for readRegistry
+		if (!exists('readRegistry')) { readRegistry <- function(...)(1) } 
+		# This is a hack to stop the check NOTE: .detectCores: no visible global function definition for 'readRegistry'
 		nn <- length(readRegistry("HARDWARE\\DESCRIPTION\\System\\CentralProcessor", maxdepth=1))
 	} else {
 		nn <- multicoreDetectCores(all.tests)
